import React from "react";
import * as d3 from 'd3';

export const Bar = ({ data, width, height }: any) => {
    const svgRef = React.useRef<SVGSVGElement>(null);

    React.useEffect(() => {
        const svg = d3.select(svgRef.current);

        // Set up scales
        const xScale = d3
            .scaleBand()
            .domain(data.map((d, i) => i))
            .range([0, width])
            .padding(0.1);

        const yScale = d3
            .scaleLinear()
            .domain([0, d3.max(data)])
            .range([height, 0]);

        // Create bars
        svg
            .selectAll('.bar')
            .data(data)
            .join('rect')
            .attr('class', 'bar')
            .attr('x', (d, i) => xScale(i))
            .attr('y', d => yScale(d))
            .attr('width', xScale.bandwidth())
            .attr('height', d => height - yScale(d));
    }, [data, width, height]);

    return (
        <svg ref={svgRef} width={width} height={height}>
        </svg>
    );
};

export default function BarChart(props: any) {

    const data = [10, 20, 30, 40, 50];
    const width = 500;
    const height = 300;

    return (
        <div>
            <h1>Affichage des données selon un diagramme à barre</h1>
            <Bar data={data} width={width} height={height} />
        </div>
    )
}