import React from "react";
import * as d3 from 'd3';

interface DataPoint {
    label: string;
    value: number;
}

interface Props {
    data: DataPoint[];
    width: number;
    height: number;
}

export const Pie = ({ data, width, height }: any) => {
    const svgRef = React.useRef<SVGSVGElement>(null);

    React.useEffect(() => {
        const svg = d3.select(svgRef.current);

        // Set up pie layout
        const pie = d3
            .pie<DataPoint>()
            .sort(null)
            .value(d => d.value);

        // Set up arc generator
        const arc = d3
            .arc<d3.PieDatum<DataPoint>>()
            .outerRadius(Math.min(width, height) / 2)
            .innerRadius(0);

        // Set up color scale
        const color = d3.scaleOrdinal(d3.schemeCategory10);

        // Create pie slices
        svg
            .selectAll('.slice')
            .data(pie(data))
            .join('path')
            .attr('class', 'slice')
            .attr('d', arc)
            .attr('fill', d => color(d.data.label));
    }, [data, width, height]);

    return (
        <svg ref={svgRef} width={width} height={height}>
            {/* Pie slices will be added here by D3 */}
        </svg>
    );
};

export default function PieChart(props: any) {

    const data = [
        { label: 'A', value: 10 },
        { label: 'B', value: 20 },
        { label: 'C', value: 30 },
        { label: 'D', value: 40 },
    ];
    const width = 500;
    const height = 300;

    return (
        <div>
            <h1>Affichage des données selon un diagramme circulaire</h1>
            <Pie data={data} width={width} height={height} />
        </div>
    )
}