import React from "react";
import * as d3 from 'd3';

const Line = ({ data, width, height }: any) => {
    const svgRef = React.useRef<SVGSVGElement>(null);

    React.useEffect(() => {
        const svg = d3.select(svgRef.current);

        // Set up scales
        const xScale = d3
            .scaleLinear()
            .domain([d3.min(data, d => d.x), d3.max(data, d => d.x)])
            .range([0, width]);

        const yScale = d3
            .scaleLinear()
            .domain([d3.min(data, d => d.y), d3.max(data, d => d.y)])
            .range([height, 0]);

        // Create line
        const line = d3
            .line<{ x: number; y: number }>()
            .x(d => xScale(d.x))
            .y(d => yScale(d.y));

        svg
            .selectAll('.line')
            .data([data])
            .join('path')
            .attr('class', 'line')
            .attr('d', line);

        // Add circles for data points
        svg
            .selectAll('.point')
            .data(data)
            .join('circle')
            .attr('class', 'point')
            .attr('cx', d => xScale(d.x))
            .attr('cy', d => yScale(d.y))
            .attr('r', 3);
    }, [data, width, height]);

    return (
        <svg ref={svgRef} width={width} height={height}>
        </svg>
    );
};

export default function TimeSeries(props: any) {

    const data = [
        { x: 0, y: 10 },
        { x: 1, y: 20 },
        { x: 2, y: 30 },
        { x: 3, y: 40 },
        { x: 4, y: 50 },
    ];
    const width = 500;
    const height = 300;

    return (
        <div>
            <h1>Affichage des données par une série temporelle</h1>
            <Line data={data} width={width} height={height} />
        </div>
    )
}